# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-09-21 14:05
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('multilingual_flatpages', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='flatpage',
            name='name',
            field=models.CharField(default='', max_length=100, verbose_name='Name'),
            preserve_default=False,
        ),
    ]
