# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-11-29 09:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('multilingual_flatpages', '0002_flatpage_name'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='flatpage',
            options={'ordering': ('slug',), 'verbose_name': 'flat page', 'verbose_name_plural': 'flat pages'},
        ),
        migrations.RemoveField(
            model_name='flatpagetranslation',
            name='url',
        ),
        migrations.AddField(
            model_name='flatpagetranslation',
            name='slug',
            field=models.CharField(db_index=True, default='', max_length=100, verbose_name='slug'),
            preserve_default=False,
        ),
    ]
