<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8">
        <title>{{obj.title}}</title>
    </head>
    <body>
        <h1>{{obj.title}}</h1>

        {{obj.content}}
    </body>
</html>
